@@ -23,13 +23,17 @@
 #' if(require("tesseract")){
 #' img <- image_read("http://jeroen.github.io/images/testocr.png")
 #' image_ocr(img)
+#' image_ocr_data(img)
 #' }
 image_ocr <- function(image, language = "eng", ...){
   assert_image(image)
-  vapply(image, function(x){
-    tmp <- tempfile(fileext = ".png")
-    on.exit(unlink(tmp))
-    buf <- image_write(x, tmp, format = 'PNG', density = "72x72")
-    tesseract::ocr(tmp, engine = tesseract::tesseract(language, ...))
-  }, character(1))
+  tesseract::ocr(image, engine = tesseract::tesseract(language, ...))
+}
+
+
+#' @export
+#' @rdname ocr
+image_ocr_data <- function(image, language = "eng", ...){
+  assert_image(image)
+  tesseract::ocr_data(image, engine = tesseract::tesseract(language, ...))
 }
